# Fena
This is a preprocessor language for Minecraft, and supports versions 1.12 and 1.13.

### Installation
* TODO

### Usage
* TODO

### Previous versions:
* CCU (Java, 1.10.x to 1.12.x): https://github.com/Aquafina-water-bottle/Fena/tree/cb62da740e1d5e040e50e1c329d35d738b22503c
* CCU2 (Python, 1.12.x): https://github.com/Aquafina-water-bottle/Fena/tree/ccu2

